@@ -1,3 +1,4 @@
+import re
 import logging
 import uuid
 from typing import List, Generator
@@ -8,13 +9,12 @@ from os.path import exists as os_exists, dirname, getctime, basename
 from shutil import copyfile
 from datetime import datetime, timedelta, timezone
 
-from retrying import retry
 from s3fs import S3FileSystem as OriginalS3FileSystem
 import boto3
 
 from shub_workflow.deliver import gcstorage
 
-
+S3_PATH_RE = re.compile("s3://(.+?)/(.+)")
 _S3_ATTRIBUTE = "s3://"
 _GS_ATTRIBUTE = "gs://"
 BUFFER = 1024 * 1024
@@ -33,9 +33,6 @@ def just_log_exception(exception):
     return True  # retries any other exception
 
 
-retry_decorator = retry(retry_on_exception=just_log_exception, wait_fixed=60000, stop_max_attempt_number=10)
-
-
 class S3FileSystem(OriginalS3FileSystem):
     read_timeout = 120
     connect_timeout = 60
@@ -173,6 +170,23 @@ def rm_file(path, aws_key=None, aws_secret=None, aws_token=None, **kwargs):
         remove(path)
 
 
+def list_path(path, aws_key=None, aws_secret=None, aws_token=None, **kwargs):
+    """
+    More efficient boto3 based path listing, that accepts prefix
+    """
+    session = boto3.Session(
+        aws_access_key_id=aws_key, aws_secret_access_key=aws_secret, aws_session_token=aws_token, **kwargs
+    )
+    if path.startswith(_S3_ATTRIBUTE):
+        s3 = session.resource("s3")
+        bucket_name, path = S3_PATH_RE.match(path).groups()
+        bucket = s3.Bucket(bucket_name)
+        for result in bucket.objects.filter(Prefix=path):
+            yield f"s3://{bucket_name}/{result.key}"
+    else:
+        raise NotImplementedError("Only implemented for s3.")
+
+
 def list_folder(path, aws_key=None, aws_secret=None, aws_token=None, **kwargs) -> List[str]:
     if path.startswith(_S3_ATTRIBUTE):
         fs = S3FileSystem(**s3_credentials(aws_key, aws_secret, aws_token), **kwargs)
@@ -330,6 +344,7 @@ class S3Helper:
             exists,
             touch,
             cp_file,
+            list_path,
             list_folder_in_ts_order,
             list_folder_files_recursive,
             s3_folder_size,
